﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using System.Diagnostics;
using System.IO;
using System.Drawing.Imaging;

namespace ImageDivider
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_DragDrop(object sender, DragEventArgs e)
        {
            AllowDrop = false;

            if (e.Data.GetDataPresent(DataFormats.FileDrop))
            {
                string[] fileNames = e.Data.GetData(DataFormats.FileDrop) as string[];
                int count = 0;
                foreach (string fileName in fileNames)
                {
                    label1.Text = "(" + count++ + "/" + fileNames.Length + ")";

                    Debug.WriteLine(fileName);
                    try
                    {
                        DivideImage(fileName);

                    }
                    catch (Exception ex)
                    {
                        Debug.WriteLine(ex);
                        throw;
                    } 
                    Application.DoEvents();
                }
            }
            label1.Text = string.Empty;

            AllowDrop = true;
        }

        private void Form1_DragEnter(object sender, DragEventArgs e)
        {
            e.Effect = DragDropEffects.All;
        }

        void DivideImage(string fileName)
        {
            string path = Path.GetDirectoryName(fileName);
            string name = Path.GetFileNameWithoutExtension(fileName);
            string ext = Path.GetExtension(fileName);

            //イメージエンコーダに関する情報を取得する
            //ImageCodecInfo ici = GetEncoderInfo("image/jpeg");
            ImageCodecInfo jpegCodec = GetEncoder(ImageFormat.Jpeg);

            using (Bitmap bmp = new Bitmap(fileName))
            {
                int width_left = bmp.Width / 2;
                int width_right = bmp.Width - width_left;

#if !true
                EncoderParameters eps_org = bmp.GetEncoderParameterList(jpegCodec.Clsid);
                EncoderParameters eps = new EncoderParameters(eps_org.Param.Length);
                for (int i = 0, max = eps_org.Param.Length; i < max; i++)
                {
                    eps.Param[i] = eps_org.Param[i];
                }

#else
                EncoderParameters eps = new EncoderParameters(2);
                eps.Param[0] = new EncoderParameter(Encoder.ColorDepth, 8L);
                eps.Param[1] = new EncoderParameter(Encoder.Quality, 75L);
#endif

                using (Bitmap bmp_left = new Bitmap(width_left, bmp.Height))
                using (Bitmap bmp_right = new Bitmap(width_right, bmp.Height))
                {
                    bmp_right.SetResolution(bmp.HorizontalResolution, bmp.VerticalResolution);
                    bmp_left.SetResolution(bmp.HorizontalResolution, bmp.VerticalResolution);
                    bmp_right.Palette = bmp.Palette;
                    bmp_left.Palette = bmp.Palette;

                    using (Graphics g_right = Graphics.FromImage(bmp_right))
                    using (Graphics g_left = Graphics.FromImage(bmp_left))
                    {
                        //right
                        Rectangle rect_right = new Rectangle(width_left, 0, bmp.Width - 1, bmp.Height - 1);
                        g_right.DrawImage(bmp, 0, 0, rect_right, GraphicsUnit.Pixel);
                        string fileName_right = path + "\\" + name + "[1]" + ext;
                        bmp_right.Save(fileName_right, jpegCodec, eps);

                        //left
                        Rectangle rect_left = new Rectangle(0, 0, width_left - 1, bmp.Height - 1);
                        g_left.DrawImage(bmp, 0, 0, rect_left, GraphicsUnit.Pixel);
                        string fileName_left = path + "\\" + name + "[2]" + ext;
                        bmp_left.Save(fileName_left, jpegCodec, eps);
                    }
                }
            }
        }

        private static ImageCodecInfo GetEncoder(ImageFormat format)
        {
            ImageCodecInfo[] codecs = ImageCodecInfo.GetImageDecoders();
            foreach (ImageCodecInfo codec in codecs)
            {
                if (codec.FormatID == format.Guid)
                {
                    return codec;
                }
            }
            return null;
        }


    }//end class
}//end namespace
